# aioqsw
Python library to control QNAP QSW devices.

## Requirements
- Python >= 3.8

## Install
```bash
pip install aioqsw
```

## Install from Source
Run the following command inside this folder
```bash
pip install --upgrade .
```

## Examples
Examples can be found in the `examples` folder
